<?php


/**
 * Based on wp_notify_moderator(), located in wp-includes/pluggable.php. 
 * Notifies the moderator of the blog about a new comment that is awaiting approval.
 *
 * @uses $wpdb
 *
 * @param int $post_id Comment ID
 * @return bool Always returns true
 */
function post_moderator($post_id) {
	global $wpdb;

	/*if( get_option( "moderation_notify" ) == 0 )
		return true;*/

	$post = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE ID=%d LIMIT 1", $post_id));
	
	// get custom
    $custom = get_post_custom($post_id);
	$location = $custom["location-text"][0]; 
    $lat = $custom["location-lat"][0];
	$lng = $custom["location-lng"][0];
    $user = $custom["user-name"][0];
	$email = $custom["user-email"][0];
    if($user==""){ $user = "Anonymous"; }

	//$comment_author_domain = @gethostbyaddr($comment->comment_author_IP);
	//$comments_waiting = $wpdb->get_var("SELECT count(comment_ID) FROM $wpdb->comments WHERE comment_approved = '0'");

	// The blogname option is escaped with esc_html on the way into the database in sanitize_option
	// we want to reverse this for the plain text arena of emails.
	$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

	// build email
	$notify_message  = sprintf( __('A new story has been posted:'), $post->post_title ) . "\r\n";
	$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
	$notify_message .= sprintf( __('Link: %s '), get_bloginfo('url').'/map/'.$post_id) . "\r\n";
	$notify_message .= sprintf( __('Author : %s '), $user) . "\r\n";
	$notify_message .= sprintf( __('E-mail : %s'), $email ) . "\r\n";
	$notify_message .= sprintf( __('Location : %s'), $location ) . "\r\n";
	$notify_message .= sprintf( __('LatLng : (%s, %s)'), $lat, $lng ) . "\r\n";
	$notify_message .= __('Story: ') . "\r\n" . $post->post_content . "\r\n\r\n";
			
	// build options
	$nonce= wp_create_nonce('my-nonce');
	if ( EMPTY_TRASH_DAYS )
		$notify_message .= sprintf( __('Trash it: %s'), "Not working yet - Use the link above."). "\r\n";//  get_bloginfo('url') . "/wp-admin/post.php?action=trash&amp;post=" . $post_id ) . "\r\n";
	else
		$notify_message .= sprintf( __('Delete it: %s'), "Not working yet - Use the link above."). "\r\n";// admin_url("post.php?post=$post_id&action=delete&_wpnonce=$nonce") ) . "\r\n";

	// headers
	$subject = sprintf( __('[%1$s] New Story: "%2$s"'), $blogname, $post->post_title );
	$admin_email = get_option('admin_email');
	$message_headers = '';

	// allow filters?
	$notify_message = apply_filters('comment_moderation_text', $notify_message, $post_id);
	$subject = apply_filters('comment_moderation_subject', $subject, $post_id);
	$message_headers = apply_filters('comment_moderation_headers', $message_headers);

	// send
	@wp_mail($admin_email, $subject, $notify_message, $message_headers);

	return true;
}





?>